@@ -1,9 +1,11 @@
-use std::convert::TryFrom;
+use core::convert::TryFrom;
 
 use crate::error::{Error, Result};
 
 /// The version of the CID.
-#[derive(PartialEq, Eq, PartialOrd, Ord, Clone, Copy, Debug)]
+#[derive(PartialEq, Eq, PartialOrd, Ord, Clone, Copy, Debug, Hash)]
+#[cfg_attr(feature = "scale-codec", derive(parity_scale_codec::Decode))]
+#[cfg_attr(feature = "scale-codec", derive(parity_scale_codec::Encode))]
 pub enum Version {
     /// CID version 0.
     V0,
